

#ifndef DM_H_
#define DM_H_
#include <vector>

/**
 * This method returns a set of eigenvalues and eigenvectors from an image's
 * affinity matrix (that together make up the image's diffusion maps) given
 * the image (with its dimensions) an affinity parameter,
 * a number of pixels to sample for an affinity matrix and an expected number
 * of eigenvalues/vectors
 * Input:
 * 	parameter: img - A vector that represents an image by channels
 * 	parameter: height - The height of the image
 * 	parameter: width - the width of the image
 * 	parameter: sigma_r - the sigma parameter for the Gaussian affinity equation
 * 	parameter: nvec - The number of eigen values to be calculated
 * 	parameter: nsamples - The number of vectors in the affinity matrix to be sampled for estimating the diffusion
 * 						maps (number of vectors in affinity matrix is number of pixels in original image)
 * 	parameter: sc A component that allows us to relate to the distance between pixels in addition to the
 *            'color-distance'. Must be between [0,1] (error checking left up to user)
 *
 * Output:
 * return value: eigenvalues The eigenvalues of the images affinity matrix
 * return value: diffusion_map The diffusion map estimate
 */
class DataMat ; 
void decompose( std::vector<float *> &img,int height, int width, double sigma_r,  int nvec, int nsamples ,double sc, std::vector<float> &eigenvalues , std::vector<DataMat> &weights);

#endif
